#ifndef CERTIFICATE_H
#define CERTIFICATE_H
/**
 * @file certificate.h
 * @brief Class around native certificates.
 *
 */

#include <QByteArray>
#include <QString>

#ifdef Q_OS_WIN
#include <windows.h>
#include <wincrypt.h>
#endif

class Certificate
{
public:
    /** @brief construct a certificate from an X509 ASN1 encoded byte array.
     **/
    Certificate(const QByteArray& asn1data);

    ~Certificate();

    /** @brief check if this certificate could be parsed */
    bool isValid() const {return mValid;}

    /** @brief get a short description of the certificate
     *
     *  This description should be used as a short overview
     *  for this certificate
     *
     **/
    QString shortDescription();

private:
    bool mValid;
    QString mShortDescription;

#ifdef Q_OS_WIN
    PCCERT_CONTEXT mPCertContext;
#endif
};
#endif
